.. image:: https://img.shields.io/pypi/v/incredible.svg
   :alt: PyPi
   :target: https://pypi.python.org/pypi/incredible
.. image:: https://img.shields.io/pypi/l/incredible.svg
   :alt: BSD-3
   :target: https://opensource.org/licenses/BSD-3-Clause

=====================================================================================
incredible
=====================================================================================

A bunch of functions for finding Bayesian credible intervals and regions.

Documentation will be added at some point. Probably.
